translate.filters.checks.CheckerConfig

Package translate :: Package filters :: Module checks :: Class CheckerConfig |
[hide private]
[frames] | no frames]

# Class CheckerConfig

source code

object representing the configuration of a checker

Instance Methods | [hide private]
__init__(self, targetlanguage=None, accelmarkers=None, varmatches=None, notranslatewords=None, musttranslatewords=None, validchars=None, punctuation=None, endpunctuation=None, ignoretags=None, canchangetags=None, criticaltests=None, credit_sources=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
List |
_init_list(self, list) initialise configuration paramaters that are lists | source code
_init_default(self, param, default) initialise parameters that can have default options | source code
update(self, otherconfig) combines the info in otherconfig into this config object | source code
updatevalidchars(self, validchars) updates the map that eliminates valid characters | source code
updatetargetlanguage(self, langcode) Updates the target language in the config to the given target language | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, targetlanguage=None, accelmarkers=None, varmatches=None, notranslatewords=None, musttranslatewords=None, validchars=None, punctuation=None, endpunctuation=None, ignoretags=None, canchangetags=None, criticaltests=None, credit_sources=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _init_list(self, list) | source code
initialise configuration paramaters that are lists Parameters: `list` (List) - None (we'll initialise a blank list) or a list paramater Returns: List

### _init_default(self, param, default) | source code
initialise parameters that can have default options Parameters: `param` - the user supplied paramater value `default` - default values when param is not specified Returns: the paramater as specified by the user of the default settings